openai.impl

Shared helpers for OpenAI SDK wrapper namespaces.

Shared helpers for OpenAI SDK wrapper namespaces.
raw docstring

->json-schema-propertiesclj

(->json-schema-properties m)
source

->json-value-propertiesclj

(->json-value-properties m)
source

->keywordclj

(->keyword s)
source

all-pagesclj

(all-pages page)

Realize each element from all pages of an SDK *ListPage with its autoPager.

Realize each element from all pages of an SDK *ListPage with its autoPager.
sourceraw docstring

encode-outputclj

(encode-output x)
source

enum-nameclj

(enum-name k)
source

json-mapperclj

source

json-value->cljclj

(json-value->clj value)
source

missing-key!clj

(missing-key! k)
source

opt-getclj

(opt-get o)
source

parse-argumentsclj

(parse-arguments s)
source

parse-jsonclj

(parse-json s)
source

sdk-object->cljclj

(sdk-object->clj value)
source

service-error-typeclj

(service-error-type e)
source

throw-normalized!clj

(throw-normalized! e)

Rethrow an SDK exception. Service and I/O errors become ex-info keyed :openai/error with the original as the cause. Other errors propagate unchanged.

Rethrow an SDK exception. Service and I/O errors become ex-info keyed
`:openai/error` with the original as the cause. Other errors propagate unchanged.
sourceraw docstring

validate-json-schemaclj

(validate-json-schema schema data)

Return JSON Schema conformance errors for parsed Clojure data. Supports structural keywords from Responses strict schemas.

Return JSON Schema conformance errors for parsed Clojure data. Supports
structural keywords from Responses strict schemas.
sourceraw docstring

with-api-errorscljmacro

(with-api-errors & body)
source

cljdoc builds & hosts documentation for Clojure/Script libraries