openai.audio

Idiomatic Clojure wrapper over the OpenAI Audio API.

Idiomatic Clojure wrapper over the OpenAI Audio API.
raw docstring

create-speechclj

(create-speech client req)

Create speech audio and return it as a byte array.

Create speech audio and return it as a byte array.
sourceraw docstring

create-transcriptionclj

(create-transcription client req)

Transcribe an audio file and return a normalized response map.

Transcribe an audio file and return a normalized response map.
sourceraw docstring

create-transcription-streamingclj

(create-transcription-streaming client req on-event)

Stream a transcription, call on-event, and return concatenated text deltas.

Stream a transcription, call `on-event`, and return concatenated text deltas.
sourceraw docstring

create-translationclj

(create-translation client req)

Translate an audio file to English and return a normalized response map.

Translate an audio file to English and return a normalized response map.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries