Idiomatic Clojure wrapper over the OpenAI Audio API.
Idiomatic Clojure wrapper over the OpenAI Audio API.
(create-speech client req)Create speech audio and return it as a byte array.
Create speech audio and return it as a byte array.
(create-transcription client req)Transcribe an audio file and return a normalized response map.
Transcribe an audio file and return a normalized response map.
(create-transcription-streaming client req on-event)Stream a transcription, call on-event, and return concatenated text deltas.
Stream a transcription, call `on-event`, and return concatenated text deltas.
(create-translation client req)Translate an audio file to English and return a normalized response map.
Translate an audio file to English and return a normalized response map.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |