Shared helpers for OpenAI SDK wrapper namespaces.
Shared helpers for OpenAI SDK wrapper namespaces.
(all-pages page)Realize each element from all pages of an SDK *ListPage with its autoPager.
Realize each element from all pages of an SDK *ListPage with its autoPager.
(throw-normalized! e)Rethrow an SDK exception. Service and I/O errors become ex-info keyed
:openai/error with the original as the cause. Other errors propagate unchanged.
Rethrow an SDK exception. Service and I/O errors become ex-info keyed `:openai/error` with the original as the cause. Other errors propagate unchanged.
(validate-json-schema schema data)Return JSON Schema conformance errors for parsed Clojure data. Supports structural keywords from Responses strict schemas.
Return JSON Schema conformance errors for parsed Clojure data. Supports structural keywords from Responses strict schemas.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |